/**
 * EasyBeans
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ChainedPropertyResolver.java 5404 2010-03-11 15:03:02Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.xmlconfig.properties;

import java.util.ArrayList;
import java.util.List;

/**
 * A {@code ChainedPropertyResolver} is responsible to call each resolver
 * from a list of resolver. The first one that returns a alue wins.
 *
 * @author Guillaume Sauthier
 */
public class ChainedPropertyResolver implements IPropertyResolver {

    /**
     * List of property resolvers.
     */
    private List<IPropertyResolver> resolvers;

    public ChainedPropertyResolver() {
        this.resolvers = new ArrayList<IPropertyResolver>();
    }

    public List<IPropertyResolver> getResolvers() {
        return this.resolvers;
    }

    public String resolve(final String name) {

        // Return the first resolved value (if any)
        for (IPropertyResolver resolver : resolvers) {
            String value = resolver.resolve(name);
            if (value != null) {
                return value;
            }
        }
        return null;
    }
}
